package com.ruoyi.framework.system.service;

import java.util.List;
import com.ruoyi.framework.system.domain.FollowUpReminders;

/**
 * 随访提醒Service接口
 * 
 * @author ruoyi
 * @date 2024-11-13
 */
public interface IFollowUpRemindersService 
{
    /**
     * 查询随访提醒
     * 
     * @param ReminderID 随访提醒主键
     * @return 随访提醒
     */
    public FollowUpReminders selectFollowUpRemindersByReminderID(Long ReminderID);

    /**
     * 查询随访提醒列表
     * 
     * @param followUpReminders 随访提醒
     * @return 随访提醒集合
     */
    public List<FollowUpReminders> selectFollowUpRemindersList(FollowUpReminders followUpReminders);

    /**
     * 新增随访提醒
     * 
     * @param followUpReminders 随访提醒
     * @return 结果
     */
    public int insertFollowUpReminders(FollowUpReminders followUpReminders);

    /**
     * 修改随访提醒
     * 
     * @param followUpReminders 随访提醒
     * @return 结果
     */
    public int updateFollowUpReminders(FollowUpReminders followUpReminders);

    /**
     * 批量删除随访提醒
     * 
     * @param ReminderIDs 需要删除的随访提醒主键集合
     * @return 结果
     */
    public int deleteFollowUpRemindersByReminderIDs(Long[] ReminderIDs);

    /**
     * 删除随访提醒信息
     * 
     * @param ReminderID 随访提醒主键
     * @return 结果
     */
    public int deleteFollowUpRemindersByReminderID(Long ReminderID);
}
